@@ -23,4 +23,9 @@ vc.VPN_Client_Management.AccountCreate(
     _NICNAME="VPN2"
 )
 vc.VPN_Client_Management.AccountConnect(name=name)
+while not vc.is_connected_to_vpn():
+    time.sleep(0.5)
+time.sleep(5)
+vc.VPN_Client_Management.AccountDisconnect(name=name)
+vc.VPN_Client_Management.AccountDelete(name=name)
 
