@@ -2,9 +2,11 @@ from subprocess import Popen, PIPE, DEVNULL
 import requests
 import csv
 import re
+import os
 import time
 import random
 from io import StringIO
+from netifaces import AF_INET, interfaces, ifaddresses
 from .helper import VPN_Tools, VPN_Client_Management, VPN_Server_VPN_Bridge_Management_For_Entire_Server, VPN_Server_VPN_Bridge_Management_For_Virtual_Hub
 
 
@@ -13,10 +15,14 @@ class VPNCMD:
     vpns: list = None
     vpns_cols: list = None
     cmd_prefix: tuple = None
+    current_vpn_name: str = None
 
-    def __init__(self, vpncmd_fp: str, debug: bool = False):
+    def __init__(self, vpncmd_fp: str, disconnect_on_exit: bool = True, debug: bool = False):
         self.vpncmd_fp = vpncmd_fp
+        if not os.path.isfile(self.vpncmd_fp):
+            raise FileNotFoundError
         self.debug = debug
+        self.disconnect_on_exit = disconnect_on_exit
         self.VPN_Tools = VPN_Tools()
         self.VPN_Tools.cmd = self.cmd
         self.VPN_Client_Management = VPN_Client_Management()
@@ -70,6 +76,16 @@ class VPNCMD:
         self.vpns = _[2:-1]
         _ = None
 
+    def get_available_nic(self, n: int = None):
+        nics = self.VPN_Client_Management.NicList()[0].decode().split("Virtual Network Adapter Name|")
+        if len(nics) == 1:
+            raise ValueError("VPN NIC does not exist, use VPNCMD.VPN_Client_Management.NicCreate first")
+        nics = [_.splitlines()[0] for _ in nics]
+        if n is None:
+            return nics
+        else:
+            return nics[n]
+
     def connect_known_vpn(self, _NICNAME: str = None):
         preferred_vpns = [_[:-1] for _ in self.filter_vpns(
             column="IP",
@@ -79,6 +95,8 @@ class VPNCMD:
         )]
         _SERVER = "{}:{}".format(random.SystemRandom().choice(preferred_vpns)[1], 443)
         self.current_vpn_name = "VPN@{}".format(_SERVER)
+        if not _NICNAME:
+            _NICNAME = self.get_available_nic(0)
         self.VPN_Client_Management.AccountCreate(
             name=self.current_vpn_name,
             _SERVER=_SERVER,
@@ -88,33 +106,38 @@ class VPNCMD:
         )
         return self.VPN_Client_Management.AccountConnect(name=self.current_vpn_name)
 
-    def disconnect_known_vpn(self, name: str = None):
-        self.VPN_Client_Management.AccountDisconnect(name)
-        time.sleep(1)
-        return self.VPN_Client_Management.AccountDelete(name)
-
     def connect_random_vpn(self, _NICNAME: str = None):
         if not self.vpns:
             self.fetch_vpns()
         vpn = random.SystemRandom().choice(self.vpns)
         _SERVER = "{}:{}".format(vpn[1], 443)
         if not _NICNAME:
-            nics = self.VPN_Client_Management.NicList()[0].decode().split("Virtual Network Adapter Name|")
-            if len(nics) == 1:
-                raise ValueError("VPN NIC does not exist, use VPNCMD.VPN_Client_Management.NicCreate first")
-            _NICNAME = nics[1].splitlines()[0]
-        name = "RANDOM VPN@{}".format(_SERVER)
-        self.VPN_Client_Management.AccountCreate(name=name, _SERVER=_SERVER, _HUB="VPNGATE", _USERNAME="vpn", _NICNAME=_NICNAME)
-        return self.VPN_Client_Management.AccountConnect(name=name)
+            _NICNAME = self.get_available_nic(0)
+        self.current_vpn_name = "RANDOM VPN@{}".format(_SERVER)
+        self.VPN_Client_Management.AccountCreate(name=self.current_vpn_name, _SERVER=_SERVER, _HUB="VPNGATE", _USERNAME="vpn", _NICNAME=_NICNAME)
+        return self.VPN_Client_Management.AccountConnect(name=self.current_vpn_name)
 
-    def disconnect_random_vpn(self):
-        vpns = self.VPN_Client_Management.AccountList()[0].decode().split("VPN Connection Setting Name |")
-        for vpn in vpns:
-            vpn = vpn.splitlines()[0]
-            if vpn.startswith("RANDOM VPN@") and vpn.endswith(":443"):
-                self.VPN_Client_Management.AccountDisconnect(name=vpn)
-                time.sleep(1)
-                return self.VPN_Client_Management.AccountDelete(name=vpn)
+    def __del__(self):
+        if self.disconnect_on_exit:
+            self.disconnect_vpn()
+
+    def disconnect_vpn(self):
+        if self.current_vpn_name:
+            self.VPN_Client_Management.AccountDisconnect(self.current_vpn_name)
+            time.sleep(1)
+            r = self.VPN_Client_Management.AccountDelete(self.current_vpn_name)
+            self.current_vpn_name = None
+            return r
+        return True
+
+    def is_connected_to_vpn(self):
+        for iface in interfaces():
+            try:
+                if re.search(r"^(10\.)", ifaddresses(iface)[AF_INET][0]['addr']):
+                    return True
+            except:
+                pass
+        return False
 
     def filter_vpns(self, column: str, value, sort: str = "Uptime", order: str = "desc"):
         if not self.vpns:
